from cantools.autosar import compute_profile2_crc
import can

class E2E():
    data_ids = None
    crc_signal_name = None
    snc_signal_name = None
    def __init__(self) -> None:
        pass


def update_e2e_autosar_profile2(msg: can.Message) -> None:
    """
    Updates the E2E protection of the message.

    Args:
    - msg (can.Message): The CAN message to be updated.
    """
    data_ids = [0x42, 0x52, 0x55, 0x53, 0x41, 0x20, 0x48, 0x59, 0x50, 0x4F, 0x57, 0x45, 0x52, 0x20, 0x41, 0x47]
    seq_counter = msg.data[1] & 0x0F
    seq_counter += 1
    seq_counter %= 16
    data_id = data_ids[seq_counter]
    crc = compute_profile2_crc(msg.data, data_id )
    msg.data[0] = crc
    msg.data[1] = (msg.data[1] & 0xF0) | seq_counter
    


from can.interface import Bus
from cantools.database import load_file
from broqer import Sink
from canbro import Node
import os
from time import sleep
import logging
logging.basicConfig(level=logging.DEBUG)

# load dbc file
db = load_file('poc/device_CAN.dbc')

# create ECU node with virtual bus test
bus_e= Bus('test', interface='virtual')
ecu = Node(name="ECU",bus=bus_e,database=db )

# create VCU node with virtual bus test, and connect to ECU via same name of bus -> test
bus_v= Bus('test', interface='virtual')
vcu= Node(name='CONTROL',bus=bus_v,database=db )

def show_singal(sig):
    print( '{} = {} {}'.format(sig._metadata.name,sig._state,sig._metadata.unit))

vcu.DEM.start_periodic()


sleep(1)

i = 0

while(1):
    sleep(1.5)
    os.system('clear')
    show_singal(ecu.DEM._signal_operation_mode)
    print('press ctrl+c to exit')
    i=i+1
    vcu.DEM._signal_operation_mode.notify(i)
    sleep(1)
    i=i%6


from .network import Network
from .node import Node
from .message import MessageRx, MessageTx
from .e2e import update_e2e_autosar_profile2

__all__ = ['Network', 'Node', 'MessageRx', 'MessageTx', 'update_e2e_autosar_profile2']